@@ -33,7 +33,7 @@ extern "C" {
     static mut stdout: *mut FILE;
 }
 
-#[cfg(all(target_os = "windows", target_env = "gnu"))]
+#[cfg(target_os = "windows")]
 extern "C" {
     fn __acrt_iob_func(idx: libc::c_uint) -> *mut FILE;
 }
@@ -45,7 +45,7 @@ macro_rules! STDIN {
     };
 }
 
-#[cfg(all(target_os = "windows", target_env = "gnu"))]
+#[cfg(target_os = "windows")]
 macro_rules! STDIN {
     () => {
         __acrt_iob_func(0)
@@ -59,7 +59,7 @@ macro_rules! STDOUT {
     };
 }
 
-#[cfg(all(target_os = "windows", target_env = "gnu"))]
+#[cfg(target_os = "windows")]
 macro_rules! STDOUT {
     () => {
         __acrt_iob_func(1)
